[![Stars](https://img.shields.io/github/stars/ericli0419/SPACE?logo=GitHub&color=yellow)](https://github.com/ericli0419/SPACE) [![PyPI](https://img.shields.io/pypi/v/space-srt.svg)](https://pypi.org/project/space-srt)

# **SP**atial transcriptomics **A**nalysis via **C**ell **E**mbedding

## Installation  	
#### install from PyPI

```shell
pip install space-srt
```

#### install from GitHub

install the latest develop version

```shell
git clone https://github.com/ericli0419/SPACE.git
cd SPACE
python setup.py install
```

SPACE is implemented in [Pytorch](https://pytorch.org/) framework.  
SPACE can be run on CPU devices, and running SPACE on GPU devices if available is recommended.   

